CreateRecordChapterRequest class

Adds a new chapter marker to the file currently being recorded.

Note: As of OBS 30.2.0, the only file format supporting this feature is Hybrid MP4.

  • Category: Record
  • Complexity: 2/5
  • RPC Version: 1
  • Initial Version: 5.5.0
Inheritance

Constructors

CreateRecordChapterRequest({String? chapterName})

Properties

chapterName String?
Name of the new chapter
final
data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
response ObsWebSocketResponse?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeResponse(dynamic data, dynamic status) ObsWebSocketResponse
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited