GetInputPropertiesListPropertyItemsResponse class
Response for GetInputPropertiesListPropertyItems
- Inheritance
-
- Object
- ObsWebSocketResponse
- GetInputPropertiesListPropertyItemsResponse
Constructors
-
GetInputPropertiesListPropertyItemsResponse(Map<
String, dynamic> data, ObsRequestResponseStatus status) - GetInputPropertiesListPropertyItemsResponse.fromResponse(dynamic resp)
Properties
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
propertyItems
→ List<
Map< String, dynamic> > -
Array of items in the list property
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ObsRequestResponseStatus
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited