GetLastReplayBufferReplayRequest class
Gets the filename of the last replay buffer save file.
- Category: Outputs
- Complexity: 2/5
- RPC Version: 1
- Initial Version: 5.0.0
- Inheritance
-
- Object
- ObsWebSocketRequest<
GetLastReplayBufferReplayResponse> - GetLastReplayBufferReplayRequest
Constructors
Properties
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- response ↔ GetLastReplayBufferReplayResponse?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serializeResponse(
dynamic data, dynamic status) → GetLastReplayBufferReplayResponse -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited