GetOutputStatusResponse class

Response for GetOutputStatus

Inheritance

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
outputActive bool
Whether the output is active
no setter
outputBytes num
Number of bytes sent by the output
no setter
outputCongestion num
Congestion of the output
no setter
outputDuration num
Current duration in milliseconds for the output
no setter
outputReconnecting bool
Whether the output is reconnecting
no setter
outputSkippedFrames num
Number of frames skipped by the output's process
no setter
outputTimecode String
Current formatted timecode string for the output
no setter
outputTotalFrames num
Total number of frames delivered by the output's process
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ObsRequestResponseStatus
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited