GetRecordStatusRequest class

Gets the status of the record output.

  • Category: Record
  • Complexity: 2/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

GetRecordStatusRequest()

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
response GetRecordStatusResponse?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeResponse(dynamic data, dynamic status) GetRecordStatusResponse
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited