ObsHelloOp class

First message sent from the server immediately on client connection. Contains authentication information if auth is required. Also contains RPC version for version negotiation.

Inheritance

Constructors

ObsHelloOp(Map<String, dynamic> data)

Properties

authentication HelloAuthentication?
Authentication info (if applicable)
no setter
code ObsWebSocketOpCode
no setteroverride
data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
obsWebSocketVersion String
obs-websocket version of the host
no setter
rpcVersion int
RPC version of the host
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited