ObsOp class abstract

Implementers

Constructors

ObsOp(Map<String, dynamic> data)

Properties

code ObsWebSocketOpCode
no setter
data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

opCodeMap → const Map<ObsWebSocketOpCode, ObsOp Function(Map<String, dynamic> data)>