ObsRequestBatchOp class

Client is making a batch of requests for obs-websocket. Requests are processed serially (in order) by the server.

Inheritance

Constructors

ObsRequestBatchOp(Map<String, dynamic> data)
ObsRequestBatchOp.create({required String requestId, bool haltOnFailure = false, ObsRequestBatchExecutionType executionType = ObsRequestBatchExecutionType.serialRealtime, required List<ObsRequestOp> requests})

Properties

code ObsWebSocketOpCode
no setteroverride
data Map<String, dynamic>
finalinherited
executionType ObsRequestBatchExecutionType
no setter
haltOnFailure bool
no setter
hashCode int
The hash code for this object.
no setterinherited
requestId String
no setter
requests List<ObsRequestOp>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited