ObsRequestOp class
Client is making a request to obs-websocket. Eg get current scene, create source.
Constructors
-
ObsRequestOp(Map<
String, dynamic> data) -
ObsRequestOp.create({required String requestType, required String requestId, Map<
String, dynamic> ? requestData})
Properties
- code → ObsWebSocketOpCode
-
no setteroverride
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestData
→ Map<
String, dynamic> ? -
no setter
- requestId → String
-
no setter
- requestType → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited