ProfileListChangedEvent class

The profile list has changed.

  • Subscription: Config
  • Category: Config
  • Complexity: 1/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

ProfileListChangedEvent(String type, Map<String, dynamic> data)

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
profiles List<String>
Updated list of profiles
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited