SceneRemovedEvent class

A scene has been removed.

  • Subscription: Scenes
  • Category: Scenes
  • Complexity: 2/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

SceneRemovedEvent(String type, Map<String, dynamic> data)

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isGroup bool
Whether the scene was a group
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sceneName String
Name of the removed scene
no setter
sceneUuid String
UUID of the removed scene
no setter
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited