SetCurrentPreviewSceneRequest class

Sets the current preview scene.

Only available when studio mode is enabled.

  • Category: Scenes
  • Complexity: 1/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

SetCurrentPreviewSceneRequest({String? sceneName, String? sceneUuid})

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
response ObsWebSocketResponse?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sceneName String?
Scene name to set as the current preview scene
final
sceneUuid String?
Scene UUID to set as the current preview scene
final
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeResponse(dynamic data, dynamic status) ObsWebSocketResponse
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited