SetCurrentSceneTransitionDurationRequest class

Sets the duration of the current scene transition, if it is not fixed.

  • Category: Transitions
  • Complexity: 2/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

SetCurrentSceneTransitionDurationRequest({required num transitionDuration})

Properties

data Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
response ObsWebSocketResponse?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration num
Duration in milliseconds
final
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeResponse(dynamic data, dynamic status) ObsWebSocketResponse
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited