SourceFilterNameChangedEvent class

The name of a source filter has changed.

  • Subscription: Filters
  • Category: Filters
  • Complexity: 2/5
  • RPC Version: 1
  • Initial Version: 5.0.0
Inheritance

Constructors

SourceFilterNameChangedEvent(String type, Map<String, dynamic> data)

Properties

data Map<String, dynamic>
finalinherited
filterName String
New name of the filter
no setter
hashCode int
The hash code for this object.
no setterinherited
oldFilterName String
Old name of the filter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceName String
The source the filter is on
no setter
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited