obs_ws library
Dart library for obs-websocket
Classes
- BroadcastCustomEventRequest
-
Broadcasts a
CustomEventto all WebSocket clients. Receivers are clients which are identified and subscribed. - CallVendorRequestRequest
- Call a request registered to a vendor.
- CallVendorRequestResponse
- Response for CallVendorRequest
- CreateInputRequest
- Creates a new input, adding it as a scene item to the specified scene.
- CreateInputResponse
- Response for CreateInput
- CreateProfileRequest
- Creates a new profile, switching to it in the process
- CreateRecordChapterRequest
- Adds a new chapter marker to the file currently being recorded.
- CreateSceneCollectionRequest
- Creates a new scene collection, switching to it in the process.
- CreateSceneItemRequest
- Creates a new scene item using a source.
- CreateSceneItemResponse
- Response for CreateSceneItem
- CreateSceneRequest
- Creates a new scene in OBS.
- CreateSceneResponse
- Response for CreateScene
- CreateSourceFilterRequest
- Creates a new filter, adding it to the specified source.
- CurrentPreviewSceneChangedEvent
- The current preview scene has changed.
- CurrentProfileChangedEvent
- The current profile has changed.
- CurrentProfileChangingEvent
- The current profile has begun changing.
- CurrentProgramSceneChangedEvent
- The current program scene has changed.
- CurrentSceneCollectionChangedEvent
- The current scene collection has changed.
- CurrentSceneCollectionChangingEvent
- The current scene collection has begun changing.
- CurrentSceneTransitionChangedEvent
- The current scene transition has changed.
- CurrentSceneTransitionDurationChangedEvent
- The current scene transition duration has changed.
- CustomEventEvent
-
Custom event emitted by
BroadcastCustomEvent. - DuplicateSceneItemRequest
- Duplicates a scene item, copying all transform and crop info.
- DuplicateSceneItemResponse
- Response for DuplicateSceneItem
- ExitStartedEvent
- OBS has begun the shutdown process.
- GetCurrentPreviewSceneRequest
- Gets the current preview scene.
- GetCurrentPreviewSceneResponse
- Response for GetCurrentPreviewScene
- GetCurrentProgramSceneRequest
- Gets the current program scene.
- GetCurrentProgramSceneResponse
- Response for GetCurrentProgramScene
- GetCurrentSceneTransitionCursorRequest
- Gets the cursor position of the current scene transition.
- GetCurrentSceneTransitionCursorResponse
- Response for GetCurrentSceneTransitionCursor
- GetCurrentSceneTransitionRequest
- Gets information about the current scene transition.
- GetCurrentSceneTransitionResponse
- Response for GetCurrentSceneTransition
- GetGroupListRequest
- Gets an array of all groups in OBS.
- GetGroupListResponse
- Response for GetGroupList
- GetGroupSceneItemListRequest
- Basically GetSceneItemList, but for groups.
- GetGroupSceneItemListResponse
- Response for GetGroupSceneItemList
- GetHotkeyListRequest
- Gets an array of all hotkey names in OBS.
- GetHotkeyListResponse
- Response for GetHotkeyList
- GetInputAudioBalanceRequest
- Gets the audio balance of an input.
- GetInputAudioBalanceResponse
- Response for GetInputAudioBalance
- GetInputAudioMonitorTypeRequest
- Gets the audio monitor type of an input.
- GetInputAudioMonitorTypeResponse
- Response for GetInputAudioMonitorType
- GetInputAudioSyncOffsetRequest
- Gets the audio sync offset of an input.
- GetInputAudioSyncOffsetResponse
- Response for GetInputAudioSyncOffset
- GetInputAudioTracksRequest
- Gets the enable state of all audio tracks of an input.
- GetInputAudioTracksResponse
- Response for GetInputAudioTracks
- GetInputDefaultSettingsRequest
- Gets the default settings for an input kind.
- GetInputDefaultSettingsResponse
- Response for GetInputDefaultSettings
- GetInputDeinterlaceFieldOrderRequest
- Gets the deinterlace field order of an input.
- GetInputDeinterlaceFieldOrderResponse
- Response for GetInputDeinterlaceFieldOrder
- GetInputDeinterlaceModeRequest
- Gets the deinterlace mode of an input.
- GetInputDeinterlaceModeResponse
- Response for GetInputDeinterlaceMode
- GetInputKindListRequest
- Gets an array of all available input kinds in OBS.
- GetInputKindListResponse
- Response for GetInputKindList
- GetInputListRequest
- Gets an array of all inputs in OBS.
- GetInputListResponse
- Response for GetInputList
- GetInputMuteRequest
- Gets the audio mute state of an input.
- GetInputMuteResponse
- Response for GetInputMute
- GetInputPropertiesListPropertyItemsRequest
- Gets the items of a list property from an input's properties.
- GetInputPropertiesListPropertyItemsResponse
- Response for GetInputPropertiesListPropertyItems
- GetInputSettingsRequest
- Gets the settings of an input.
- GetInputSettingsResponse
- Response for GetInputSettings
- GetInputVolumeRequest
- Gets the current volume setting of an input.
- GetInputVolumeResponse
- Response for GetInputVolume
- GetLastReplayBufferReplayRequest
- Gets the filename of the last replay buffer save file.
- GetLastReplayBufferReplayResponse
- Response for GetLastReplayBufferReplay
- GetMediaInputStatusRequest
- Gets the status of a media input.
- GetMediaInputStatusResponse
- Response for GetMediaInputStatus
- GetMonitorListRequest
- Gets a list of connected monitors and information about them.
- GetMonitorListResponse
- Response for GetMonitorList
- GetOutputListRequest
- Gets the list of available outputs.
- GetOutputListResponse
- Response for GetOutputList
- GetOutputSettingsRequest
- Gets the settings of an output.
- GetOutputSettingsResponse
- Response for GetOutputSettings
- GetOutputStatusRequest
- Gets the status of an output.
- GetOutputStatusResponse
- Response for GetOutputStatus
- GetPersistentDataRequest
- Gets the value of a "slot" from the selected persistent data realm.
- GetPersistentDataResponse
- Response for GetPersistentData
- GetProfileListRequest
- Gets an array of all profiles
- GetProfileListResponse
- Response for GetProfileList
- GetProfileParameterRequest
- Gets a parameter from the current profile's configuration.
- GetProfileParameterResponse
- Response for GetProfileParameter
- GetRecordDirectoryRequest
- Gets the current directory that the record output is set to.
- GetRecordDirectoryResponse
- Response for GetRecordDirectory
- GetRecordStatusRequest
- Gets the status of the record output.
- GetRecordStatusResponse
- Response for GetRecordStatus
- GetReplayBufferStatusRequest
- Gets the status of the replay buffer output.
- GetReplayBufferStatusResponse
- Response for GetReplayBufferStatus
- GetSceneCollectionListRequest
- Gets an array of all scene collections
- GetSceneCollectionListResponse
- Response for GetSceneCollectionList
- GetSceneItemBlendModeRequest
- Gets the blend mode of a scene item.
- GetSceneItemBlendModeResponse
- Response for GetSceneItemBlendMode
- GetSceneItemEnabledRequest
- Gets the enable state of a scene item.
- GetSceneItemEnabledResponse
- Response for GetSceneItemEnabled
- GetSceneItemIdRequest
- Searches a scene for a source, and returns its id.
- GetSceneItemIdResponse
- Response for GetSceneItemId
- GetSceneItemIndexRequest
- Gets the index position of a scene item in a scene.
- GetSceneItemIndexResponse
- Response for GetSceneItemIndex
- GetSceneItemListRequest
- Gets a list of all scene items in a scene.
- GetSceneItemListResponse
- Response for GetSceneItemList
- GetSceneItemLockedRequest
- Gets the lock state of a scene item.
- GetSceneItemLockedResponse
- Response for GetSceneItemLocked
- GetSceneItemSourceRequest
- Gets the source associated with a scene item.
- GetSceneItemSourceResponse
- Response for GetSceneItemSource
- GetSceneItemTransformRequest
- Gets the transform and crop info of a scene item.
- GetSceneItemTransformResponse
- Response for GetSceneItemTransform
- GetSceneListRequest
- Gets an array of all scenes in OBS.
- GetSceneListResponse
- Response for GetSceneList
- GetSceneSceneTransitionOverrideRequest
- Gets the scene transition overridden for a scene.
- GetSceneSceneTransitionOverrideResponse
- Response for GetSceneSceneTransitionOverride
- GetSceneTransitionListRequest
- Gets an array of all scene transitions in OBS.
- GetSceneTransitionListResponse
- Response for GetSceneTransitionList
- GetSourceActiveRequest
- Gets the active and show state of a source.
- GetSourceActiveResponse
- Response for GetSourceActive
- GetSourceFilterDefaultSettingsRequest
- Gets the default settings for a filter kind.
- GetSourceFilterDefaultSettingsResponse
- Response for GetSourceFilterDefaultSettings
- GetSourceFilterKindListRequest
- Gets an array of all available source filter kinds.
- GetSourceFilterKindListResponse
- Response for GetSourceFilterKindList
- GetSourceFilterListRequest
- Gets an array of all of a source's filters.
- GetSourceFilterListResponse
- Response for GetSourceFilterList
- GetSourceFilterRequest
- Gets the info for a specific source filter.
- GetSourceFilterResponse
- Response for GetSourceFilter
- GetSourceScreenshotRequest
- Gets a Base64-encoded screenshot of a source.
- GetSourceScreenshotResponse
- Response for GetSourceScreenshot
- GetSpecialInputsRequest
- Gets the names of all special inputs.
- GetSpecialInputsResponse
- Response for GetSpecialInputs
- GetStatsRequest
- Gets statistics about OBS, obs-websocket, and the current session.
- GetStatsResponse
- Response for GetStats
- GetStreamServiceSettingsRequest
- Gets the current stream service settings (stream destination).
- GetStreamServiceSettingsResponse
- Response for GetStreamServiceSettings
- GetStreamStatusRequest
- Gets the status of the stream output.
- GetStreamStatusResponse
- Response for GetStreamStatus
- GetStudioModeEnabledRequest
- Gets whether studio is enabled.
- GetStudioModeEnabledResponse
- Response for GetStudioModeEnabled
- GetTransitionKindListRequest
- Gets an array of all available transition kinds.
- GetTransitionKindListResponse
- Response for GetTransitionKindList
- GetVersionRequest
- Gets data about the current plugin and RPC version.
- GetVersionResponse
- Response for GetVersion
- GetVideoSettingsRequest
- Gets the current video settings.
- GetVideoSettingsResponse
- Response for GetVideoSettings
- GetVirtualCamStatusRequest
- Gets the status of the virtualcam output.
- GetVirtualCamStatusResponse
- Response for GetVirtualCamStatus
- HelloAuthentication
- Authentication info sent by HelloOp required to the authenticate the client to the host
- InputActiveStateChangedEvent
- An input's active state has changed.
- InputAudioBalanceChangedEvent
- The audio balance value of an input has changed.
- InputAudioMonitorTypeChangedEvent
- The monitor type of an input has changed.
- InputAudioSyncOffsetChangedEvent
- The sync offset of an input has changed.
- InputAudioTracksChangedEvent
- The audio tracks of an input have changed.
- InputCreatedEvent
- An input has been created.
- InputMuteStateChangedEvent
- An input's mute state has changed.
- InputNameChangedEvent
- The name of an input has changed.
- InputRemovedEvent
- An input has been removed.
- InputSettingsChangedEvent
- An input's settings have changed (been updated).
- InputShowStateChangedEvent
- An input's show state has changed.
- InputVolumeChangedEvent
- An input's volume level has changed.
- InputVolumeMetersEvent
- A high-volume event providing volume levels of all active inputs every 50 milliseconds.
- MediaInputActionTriggeredEvent
- An action has been performed on an input.
- MediaInputPlaybackEndedEvent
- A media input has finished playing.
- MediaInputPlaybackStartedEvent
- A media input has started playing.
- ObsEventOp
- An event coming from OBS has occured. Eg scene switched, source muted.
- ObsHelloOp
- First message sent from the server immediately on client connection. Contains authentication information if auth is required. Also contains RPC version for version negotiation.
- ObsIdentifiedOp
- The identify request was received and validated, and the connection is now ready for normal operation.
- ObsIdentifyOp
-
Response to
Hellomessage, should contain authentication string if authentication is required, along with PubSub subscriptions and other session parameters. - ObsOp
- ObsReidentifyOp
- Sent at any time after initial identification to update the provided session parameters.
- ObsRequestBatchOp
- Client is making a batch of requests for obs-websocket. Requests are processed serially (in order) by the server.
- ObsRequestBatchResponseOp
- obs-websocket is responding to a request batch coming from the client.
- ObsRequestOp
- Client is making a request to obs-websocket. Eg get current scene, create source.
- ObsRequestResponseOp
- obs-websocket is responding to a request coming from a client.
- ObsRequestResponseStatus
- ObsWebSocket
- ObsWebSocketAuthException
- ObsWebSocketEvent
-
ObsWebSocketRequest<
T extends ObsWebSocketResponse> - ObsWebSocketRequestException
- ObsWebSocketResponse
- OffsetMediaInputCursorRequest
- Offsets the current cursor position of a media input by the specified value.
- OpenInputFiltersDialogRequest
- Opens the filters dialog of an input.
- OpenInputInteractDialogRequest
- Opens the interact dialog of an input.
- OpenInputPropertiesDialogRequest
- Opens the properties dialog of an input.
- OpenSourceProjectorRequest
- Opens a projector for a source.
- OpenVideoMixProjectorRequest
- Opens a projector for a specific output video mix.
- PauseRecordRequest
- Pauses the record output.
- PressInputPropertiesButtonRequest
- Presses a button in the properties of an input.
- ProfileListChangedEvent
- The profile list has changed.
- RecordFileChangedEvent
- The record output has started writing to a new file. For example, when a file split happens.
- RecordStateChangedEvent
- The state of the record output has changed.
- RemoveInputRequest
- Removes an existing input.
- RemoveProfileRequest
- Removes a profile. If the current profile is chosen, it will change to a different profile first.
- RemoveSceneItemRequest
- Removes a scene item from a scene.
- RemoveSceneRequest
- Removes a scene from OBS.
- RemoveSourceFilterRequest
- Removes a filter from a source.
- ReplayBufferSavedEvent
- The replay buffer has been saved.
- ReplayBufferStateChangedEvent
- The state of the replay buffer output has changed.
- ResumeRecordRequest
- Resumes the record output.
- SaveReplayBufferRequest
- Saves the contents of the replay buffer output.
- SaveSourceScreenshotRequest
- Saves a screenshot of a source to the filesystem.
- SceneCollectionListChangedEvent
- The scene collection list has changed.
- SceneCreatedEvent
- A new scene has been created.
- SceneItemCreatedEvent
- A scene item has been created.
- SceneItemEnableStateChangedEvent
- A scene item's enable state has changed.
- SceneItemListReindexedEvent
- A scene's item list has been reindexed.
- SceneItemLockStateChangedEvent
- A scene item's lock state has changed.
- SceneItemRemovedEvent
- A scene item has been removed.
- SceneItemSelectedEvent
- A scene item has been selected in the Ui.
- SceneItemTransformChangedEvent
- The transform/crop of a scene item has changed.
- SceneListChangedEvent
- The list of scenes has changed.
- SceneNameChangedEvent
- The name of a scene has changed.
- SceneRemovedEvent
- A scene has been removed.
- SceneTransitionEndedEvent
- A scene transition has completed fully.
- SceneTransitionStartedEvent
- A scene transition has started.
- SceneTransitionVideoEndedEvent
- A scene transition's video has completed fully.
- ScreenshotSavedEvent
- A screenshot has been saved.
- SendStreamCaptionRequest
- Sends CEA-608 caption text over the stream output.
- SetCurrentPreviewSceneRequest
- Sets the current preview scene.
- SetCurrentProfileRequest
- Switches to a profile.
- SetCurrentProgramSceneRequest
- Sets the current program scene.
- SetCurrentSceneCollectionRequest
- Switches to a scene collection.
- SetCurrentSceneTransitionDurationRequest
- Sets the duration of the current scene transition, if it is not fixed.
- SetCurrentSceneTransitionRequest
- Sets the current scene transition.
- SetCurrentSceneTransitionSettingsRequest
- Sets the settings of the current scene transition.
- SetInputAudioBalanceRequest
- Sets the audio balance of an input.
- SetInputAudioMonitorTypeRequest
- Sets the audio monitor type of an input.
- SetInputAudioSyncOffsetRequest
- Sets the audio sync offset of an input.
- SetInputAudioTracksRequest
- Sets the enable state of audio tracks of an input.
- SetInputDeinterlaceFieldOrderRequest
- Sets the deinterlace field order of an input.
- SetInputDeinterlaceModeRequest
- Sets the deinterlace mode of an input.
- SetInputMuteRequest
- Sets the audio mute state of an input.
- SetInputNameRequest
- Sets the name of an input (rename).
- SetInputSettingsRequest
- Sets the settings of an input.
- SetInputVolumeRequest
- Sets the volume setting of an input.
- SetMediaInputCursorRequest
- Sets the cursor position of a media input.
- SetOutputSettingsRequest
- Sets the settings of an output.
- SetPersistentDataRequest
- Sets the value of a "slot" from the selected persistent data realm.
- SetProfileParameterRequest
- Sets the value of a parameter in the current profile's configuration.
- SetRecordDirectoryRequest
- Sets the current directory that the record output writes files to.
- SetSceneItemBlendModeRequest
- Sets the blend mode of a scene item.
- SetSceneItemEnabledRequest
- Sets the enable state of a scene item.
- SetSceneItemIndexRequest
- Sets the index position of a scene item in a scene.
- SetSceneItemLockedRequest
- Sets the lock state of a scene item.
- SetSceneItemTransformRequest
- Sets the transform and crop info of a scene item.
- SetSceneNameRequest
- Sets the name of a scene (rename).
- SetSceneSceneTransitionOverrideRequest
- Sets the scene transition overridden for a scene.
- SetSourceFilterEnabledRequest
- Sets the enable state of a source filter.
- SetSourceFilterIndexRequest
- Sets the index position of a filter on a source.
- SetSourceFilterNameRequest
- Sets the name of a source filter (rename).
- SetSourceFilterSettingsRequest
- Sets the settings of a source filter.
- SetStreamServiceSettingsRequest
- Sets the current stream service settings (stream destination).
- SetStudioModeEnabledRequest
- Enables or disables studio mode
- SetTBarPositionRequest
- Sets the position of the TBar.
- SetVideoSettingsRequest
- Sets the current video settings.
- SleepRequest
-
Sleeps for a time duration or number of frames. Only available in request batches with types
SERIAL_REALTIMEorSERIAL_FRAME. - SourceFilterCreatedEvent
- A filter has been added to a source.
- SourceFilterEnableStateChangedEvent
- A source filter's enable state has changed.
- SourceFilterListReindexedEvent
- A source's filter list has been reindexed.
- SourceFilterNameChangedEvent
- The name of a source filter has changed.
- SourceFilterRemovedEvent
- A filter has been removed from a source.
- SourceFilterSettingsChangedEvent
- An source filter's settings have changed (been updated).
- SplitRecordFileRequest
- Splits the current file being recorded into a new file.
- StartOutputRequest
- Starts an output.
- StartRecordRequest
- Starts the record output.
- StartReplayBufferRequest
- Starts the replay buffer output.
- StartStreamRequest
- Starts the stream output.
- StartVirtualCamRequest
- Starts the virtualcam output.
- StopOutputRequest
- Stops an output.
- StopRecordRequest
- Stops the record output.
- StopRecordResponse
- Response for StopRecord
- StopReplayBufferRequest
- Stops the replay buffer output.
- StopStreamRequest
- Stops the stream output.
- StopVirtualCamRequest
- Stops the virtualcam output.
- StreamStateChangedEvent
- The state of the stream output has changed.
- StudioModeStateChangedEvent
- Studio mode has been enabled or disabled.
- ToggleInputMuteRequest
- Toggles the audio mute state of an input.
- ToggleInputMuteResponse
- Response for ToggleInputMute
- ToggleOutputRequest
- Toggles the status of an output.
- ToggleOutputResponse
- Response for ToggleOutput
- ToggleRecordPauseRequest
- Toggles pause on the record output.
- ToggleRecordRequest
- Toggles the status of the record output.
- ToggleRecordResponse
- Response for ToggleRecord
- ToggleReplayBufferRequest
- Toggles the state of the replay buffer output.
- ToggleReplayBufferResponse
- Response for ToggleReplayBuffer
- ToggleStreamRequest
- Toggles the status of the stream output.
- ToggleStreamResponse
- Response for ToggleStream
- ToggleVirtualCamRequest
- Toggles the state of the virtualcam output.
- ToggleVirtualCamResponse
- Response for ToggleVirtualCam
- TriggerHotkeyByKeySequenceRequest
- Triggers a hotkey using a sequence of keys.
- TriggerHotkeyByNameRequest
-
Triggers a hotkey using its name. See
GetHotkeyList. - TriggerMediaInputActionRequest
- Triggers an action on a media input.
- TriggerStudioModeTransitionRequest
-
Triggers the current scene transition. Same functionality as the
Transitionbutton in studio mode. - VendorEventEvent
- An event has been emitted from a vendor.
- VirtualcamStateChangedEvent
- The state of the virtualcam output has changed.