MediaInputPlaybackStartedEvent class
A media input has started playing.
- Subscription: MediaInputs
- Category: Media inputs
- Complexity: 2/5
- RPC Version: 1
- Initial Version: 5.0.0
- Inheritance
-
- Object
- ObsWebSocketEvent
- MediaInputPlaybackStartedEvent
Constructors
-
MediaInputPlaybackStartedEvent(String type, Map<
String, dynamic> data)
Properties
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputName → String
-
Name of the input
no setter
- inputUuid → String
-
UUID of the input
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited