RemoveSceneItemRequest class
Removes a scene item from a scene.
Scenes only
- Category: Scene items
- Complexity: 3/5
- RPC Version: 1
- Initial Version: 5.0.0
- Inheritance
-
- Object
- ObsWebSocketRequest<
ObsWebSocketResponse> - RemoveSceneItemRequest
Constructors
- RemoveSceneItemRequest({String? sceneName, String? sceneUuid, required num sceneItemId})
Properties
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- response ↔ ObsWebSocketResponse?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sceneItemId → num
-
Numeric ID of the scene item
final
- sceneName → String?
-
Name of the scene the item is in
final
- sceneUuid → String?
-
UUID of the scene the item is in
final
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serializeResponse(
dynamic data, dynamic status) → ObsWebSocketResponse -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited