SceneTransitionVideoEndedEvent class
A scene transition's video has completed fully.
Useful for stinger transitions to tell when the video actually ends.
SceneTransitionEnded only signifies the cut point, not the completion of transition playback.
Note: Appears to be called by every transition, regardless of relevance.
- Subscription: Transitions
- Category: Transitions
- Complexity: 2/5
- RPC Version: 1
- Initial Version: 5.0.0
- Inheritance
-
- Object
- ObsWebSocketEvent
- SceneTransitionVideoEndedEvent
Constructors
-
SceneTransitionVideoEndedEvent(String type, Map<
String, dynamic> data)
Properties
-
data
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionName → String
-
Scene transition name
no setter
- transitionUuid → String
-
Scene transition UUID
no setter
- type ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited